from citrination_client.search.pif.query.core.base_object_query import BaseObjectQuery
from citrination_client.search.pif.query.core.field_operation import FieldOperation


class QuantityQuery(BaseObjectQuery):
    """
    Class to query against a PIF Quantity object.
    """

    def __init__(self, actual_mass_percent=None, actual_volume_percent=None, actual_number_percent=None,
                 ideal_mass_percent=None, ideal_volume_percent=None, ideal_number_percent=None, logic=None,
                 tags=None, length=None, offset=None):
        """
        Constructor.

        :param actual_mass_percent: One or more :class:`FieldOperation` operations against the actual mass
        percent field.
        :param actual_volume_percent: One or more :class:`FieldOperation` operations against the actual volume
        percent field.
        :param actual_number_percent: One or more :class:`FieldOperation` operations against the actual number
        percent field.
        :param ideal_mass_percent: One or more :class:`FieldOperation` operations against the ideal mass
        percent field.
        :param ideal_volume_percent: One or more :class:`FieldOperation` operations against the ideal volume
        percent field.
        :param ideal_number_percent: One or more :class:`FieldOperation` operations against the ideal number
        percent field.
        :param logic: Logic for this filter. Must be equal to one of "MUST", "MUST_NOT", "SHOULD", or "OPTIONAL".
        :param tags: One or more :class:`FieldOperation` operations against the tags field.
        :param length: One or more :class:`FieldOperation` operations against the length field.
        :param offset: One or more :class:`FieldOperation` operations against the offset field.
        """
        super(QuantityQuery, self).__init__(logic=logic, tags=tags, length=length, offset=offset)
        self._actual_mass_percent = None
        self.actual_mass_percent = actual_mass_percent
        self._actual_volume_percent = None
        self.actual_volume_percent = actual_volume_percent
        self._actual_number_percent = None
        self.actual_number_percent = actual_number_percent
        self._ideal_mass_percent = None
        self.ideal_mass_percent = ideal_mass_percent
        self._ideal_volume_percent = None
        self.ideal_volume_percent = ideal_volume_percent
        self._ideal_number_percent = None
        self.ideal_number_percent = ideal_number_percent

    @property
    def actual_mass_percent(self):
        return self._actual_mass_percent

    @actual_mass_percent.setter
    def actual_mass_percent(self, actual_mass_percent):
        self._actual_mass_percent = self._get_object(FieldOperation, actual_mass_percent)

    @actual_mass_percent.deleter
    def actual_mass_percent(self):
        self._actual_mass_percent = None

    @property
    def actual_volume_percent(self):
        return self._actual_volume_percent

    @actual_volume_percent.setter
    def actual_volume_percent(self, actual_volume_percent):
        self._actual_volume_percent = self._get_object(FieldOperation, actual_volume_percent)

    @actual_volume_percent.deleter
    def actual_volume_percent(self):
        self._actual_volume_percent = None

    @property
    def actual_number_percent(self):
        return self._actual_number_percent

    @actual_number_percent.setter
    def actual_number_percent(self, actual_number_percent):
        self._actual_number_percent = self._get_object(FieldOperation, actual_number_percent)

    @actual_number_percent.deleter
    def actual_number_percent(self):
        self._actual_number_percent = None

    @property
    def ideal_mass_percent(self):
        return self._ideal_mass_percent

    @ideal_mass_percent.setter
    def ideal_mass_percent(self, ideal_mass_percent):
        self._ideal_mass_percent = self._get_object(FieldOperation, ideal_mass_percent)

    @ideal_mass_percent.deleter
    def ideal_mass_percent(self):
        self._ideal_mass_percent = None

    @property
    def ideal_volume_percent(self):
        return self._ideal_volume_percent

    @ideal_volume_percent.setter
    def ideal_volume_percent(self, ideal_volume_percent):
        self._ideal_volume_percent = self._get_object(FieldOperation, ideal_volume_percent)

    @ideal_volume_percent.deleter
    def ideal_volume_percent(self):
        self._ideal_volume_percent = None

    @property
    def ideal_number_percent(self):
        return self._ideal_number_percent

    @ideal_number_percent.setter
    def ideal_number_percent(self, ideal_number_percent):
        self._ideal_number_percent = self._get_object(FieldOperation, ideal_number_percent)

    @ideal_number_percent.deleter
    def ideal_number_percent(self):
        self._ideal_number_percent = None



from pypif.util.serializable import Serializable
from citrination_client.search.pif.query.core.field_operation import FieldOperation


class BaseObjectQuery(Serializable):
    """
    Base class for all PIF object queries.
    """

    def __init__(self, logic=None, tags=None, length=None, offset=None):
        """
        Constructor.

        :param logic: Logic for this filter. Must be equal to one of "MUST", "MUST_NOT", "SHOULD", or "OPTIONAL".
        :param tags: One or more :class:`FieldOperation` operations against the tags field.
        :param length: One or more :class:`FieldOperation` operations against the length field.
        :param offset: One or more :class:`FieldOperation` operations against the offset field.
        """
        self._logic = None
        self.logic = logic
        self._tags = None
        self.tags = tags
        self._length = None
        self.length = length
        self._offset = None
        self.offset = offset

    @property
    def logic(self):
        return self._logic

    @logic.setter
    def logic(self, logic):
        self._logic = logic

    @logic.deleter
    def logic(self):
        self._logic = None

    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, tags):
        self._tags = self._get_object(FieldOperation, tags)

    @tags.deleter
    def tags(self):
        self._tags = None

    @property
    def length(self):
        return self._length

    @length.setter
    def length(self, length):
        self._length = self._get_object(FieldOperation, length)

    @length.deleter
    def length(self):
        self._length = None

    @property
    def offset(self):
        return self._offset

    @offset.setter
    def offset(self, offset):
        self._offset = self._get_object(FieldOperation, offset)

    @offset.deleter
    def offset(self):
        self._offset = None



from citrination_client.search.pif.query.core.base_object_query import BaseObjectQuery
from citrination_client.search.pif.query.core.field_operation import FieldOperation


class SourceQuery(BaseObjectQuery):
    """
    Class to query against a PIF Source object.
    """

    def __init__(self, producer=None, url=None, logic=None, tags=None, length=None, offset=None):
        """
        Constructor.

        :param producer: One or more :class:`FieldOperation` operations against the producer field.
        :param url: One or more :class:`FieldOperation` operations against the url field.
        :param logic: Logic for this filter. Must be equal to one of "MUST", "MUST_NOT", "SHOULD", or "OPTIONAL".
        :param tags: One or more :class:`FieldOperation` operations against the tags field.
        :param length: One or more :class:`FieldOperation` operations against the length field.
        :param offset: One or more :class:`FieldOperation` operations against the offset field.
        """
        super(SourceQuery, self).__init__(logic=logic, tags=tags, length=length, offset=offset)
        self._producer = None
        self.producer = producer
        self._url = None
        self.url = url

    @property
    def producer(self):
        return self._producer

    @producer.setter
    def producer(self, producer):
        self._producer = self._get_object(FieldOperation, producer)

    @producer.deleter
    def producer(self):
        self._producer = None

    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, url):
        self._url = self._get_object(FieldOperation, url)

    @url.deleter
    def url(self):
        self._url = None



from citrination_client.search.pif.query.core.base_object_query import BaseObjectQuery
from citrination_client.search.pif.query.core.field_operation import FieldOperation
from citrination_client.search.pif.query.core.units_normalization import UnitsNormalization


class ValueQuery(BaseObjectQuery):
    """
    Class to query against a single value.
    """

    def __init__(self, name=None, value=None, units=None, units_normalization=None, logic=None, tags=None,
                 length=None, offset=None):
        """
        Constructor.

        :param name: One or more :class:`FieldOperation` operations against the name field.
        :param value: One or more :class:`FieldOperation` operations against the value.
        :param units: One or more :class:`FieldOperation` operations against the units field.
        :param units_normalization: :class:`UnitsNormalization` object for normalizing units.
        :param logic: Logic for this filter. Must be equal to one of "MUST", "MUST_NOT", "SHOULD", or "OPTIONAL".
        :param tags: One or more :class:`FieldOperation` operations against the tags field.
        :param length: One or more :class:`FieldOperation` operations against the length field.
        :param offset: One or more :class:`FieldOperation` operations against the offset field.
        """
        super(ValueQuery, self).__init__(logic=logic, tags=tags, length=length, offset=offset)
        self._name = None
        self.name = name
        self._value = None
        self.value = value
        self._units = None
        self.units = units
        self._units_normalization = None
        self.units_normalization = units_normalization

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, name):
        self._name = self._get_object(FieldOperation, name)

    @name.deleter
    def name(self):
        self._name = None

    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = self._get_object(FieldOperation, value)

    @value.deleter
    def value(self):
        self._value = None

    @property
    def units(self):
        return self._units

    @units.setter
    def units(self, units):
        self._units = self._get_object(FieldOperation, units)

    @units.deleter
    def units(self):
        self._units = None

    @property
    def units_normalization(self):
        return self._units_normalization

    @units_normalization.setter
    def units_normalization(self, units_normalization):
        self._units_normalization = self._get_object(UnitsNormalization, units_normalization)

    @units_normalization.deleter
    def units_normalization(self):
        self._units_normalization = None



from pypif.util.serializable import Serializable


class SortExtracted(Serializable):
    """
    Class with information about sorting on an extracted field.
    """

    def __init__(self, extract_as, sort):
        """
        Constructor.

        :param extract_as: String with the label of the extract value to sort on.
        :param sort: String equal to one of "ASCENDING" or "DESCENDING".
        """
        self._extract_as = None
        self.extract_as = extract_as
        self._sort = None
        self.sort = sort

    @property
    def extract_as(self):
        return self._extract_as

    @extract_as.setter
    def extract_as(self, extract_as):
        self._extract_as = extract_as

    @extract_as.deleter
    def extract_as(self):
        self._extract_as = None

    @property
    def sort(self):
        return self._sort

    @sort.setter
    def sort(self, sort):
        self._sort = sort

    @sort.deleter
    def sort(self):
        self._sort = None



from citrination_client.search.pif.query.core.value_query import ValueQuery
from citrination_client.search.pif.query.core.field_operation import FieldOperation


class PropertyQuery(ValueQuery):
    """
    Class to query against a single property.
    """

    def __init__(self, conditions=None, data_type=None, name=None, value=None, units=None, units_normalization=None,
                 logic=None, tags=None, length=None, offset=None):
        """
        Constructor.

        :param conditions: One or more :class:`ValueQuery` operations against the conditions.
        :param data_type: One or more :class:`FieldOperation` operations against the dataType field.
        :param name: One or more :class:`FieldOperation` operations against the name field.
        :param value: One or more :class:`FieldOperation` operations against the value.
        :param units: One or more :class:`FieldOperation` operations against the units field.
        :param units_normalization: :class:`UnitsNormalization` object for normalizing units.
        :param logic: Logic for this filter. Must be equal to one of "MUST", "MUST_NOT", "SHOULD", or "OPTIONAL".
        :param tags: One or more :class:`FieldOperation` operations against the tags field.
        :param length: One or more :class:`FieldOperation` operations against the length field.
        :param offset: One or more :class:`FieldOperation` operations against the offset field.
        """
        super(PropertyQuery, self).__init__(name=name, value=value, units=units,
                                            units_normalization=units_normalization, logic=logic, tags=tags,
                                            length=length, offset=offset)
        self._conditions = None
        self.conditions = conditions
        self._data_type = None
        self.data_type = data_type

    @property
    def conditions(self):
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        self._conditions = self._get_object(ValueQuery, conditions)

    @conditions.deleter
    def conditions(self):
        self._conditions = None

    @property
    def data_type(self):
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        self._data_type = self._get_object(FieldOperation, data_type)

    @data_type.deleter
    def data_type(self):
        self._data_type = None



from citrination_client.search.pif.query.chemical.chemical_filter import ChemicalFilter
from citrination_client.search.pif.query.core.base_field_operation import BaseFieldOperation


class ChemicalFieldOperation(BaseFieldOperation):
    """
    Class for all field operations against chemical information.
    """

    def __init__(self, filter=None, extract_as=None, length=None, offset=None):
        """
        Constructor.

        :param extract_as: String with the alias to save this field under.
        :param length: One or more :class:`.FieldOperation` objects against the length field.
        :param offset: One or more :class:`.FieldOperation` objects against the offset field.
        :param filter: One or more :class:`.ChemicalFilter` objects against this field.
        """
        super(ChemicalFieldOperation, self).__init__(extract_as=extract_as, length=length, offset=offset)
        self._filter = None
        self.filter = filter

    @property
    def filter(self):
        return self._filter

    @filter.setter
    def filter(self, filter):
        self._filter = self._get_object(ChemicalFilter, filter)

    @filter.deleter
    def filter(self):
        self._filter = None



from citrination_client.search.pif.query.chemical.chemical_field_operation import ChemicalFieldOperation
from citrination_client.search.pif.query.core.base_object_query import BaseObjectQuery
from citrination_client.search.pif.query.core.field_operation import FieldOperation


class CompositionQuery(BaseObjectQuery):
    """
    Class to query against a PIF Composition object.
    """

    def __init__(self, element=None, actual_weight_percent=None, actual_atomic_percent=None,
                 ideal_weight_percent=None, ideal_atomic_percent=None, logic=None, tags=None,
                 length=None, offset=None):
        """
        Constructor.

        :param element: One or more :class:`ChemicalFieldOperation` operations against the element field.
        :param actual_weight_percent: One or more :class:`FieldOperation` operations against the actual
        weight percent field.
        :param actual_atomic_percent: One or more :class:`FieldOperation` operations against the actual
        atomic percent field.
        :param ideal_weight_percent: One or more :class:`FieldOperation` operations against the ideal
        weight percent field.
        :param ideal_atomic_percent: One or more :class:`FieldOperation` operations against the ideal
        atomic percent field.
        :param logic: Logic for this filter. Must be equal to one of "MUST", "MUST_NOT", "SHOULD", or "OPTIONAL".
        :param tags: One or more :class:`FieldOperation` operations against the tags field.
        :param length: One or more :class:`FieldOperation` operations against the length field.
        :param offset: One or more :class:`FieldOperation` operations against the offset field.
        """
        super(CompositionQuery, self).__init__(logic=logic, tags=tags, length=length, offset=offset)
        self._element = None
        self.element = element
        self._actual_weight_percent = None
        self.actual_weight_percent = actual_weight_percent
        self._actual_atomic_percent = None
        self.actual_atomic_percent = actual_atomic_percent
        self._ideal_weight_percent = None
        self.ideal_weight_percent = ideal_weight_percent
        self._ideal_atomic_percent = None
        self.ideal_atomic_percent = ideal_atomic_percent

    @property
    def element(self):
        return self._element

    @element.setter
    def element(self, element):
        self._element = self._get_object(ChemicalFieldOperation, element)

    @element.deleter
    def element(self):
        self._element = None

    @property
    def actual_weight_percent(self):
        return self._actual_weight_percent

    @actual_weight_percent.setter
    def actual_weight_percent(self, actual_weight_percent):
        self._actual_weight_percent = self._get_object(FieldOperation, actual_weight_percent)

    @actual_weight_percent.deleter
    def actual_weight_percent(self):
        self._actual_weight_percent = None

    @property
    def actual_atomic_percent(self):
        return self._actual_atomic_percent

    @actual_atomic_percent.setter
    def actual_atomic_percent(self, actual_atomic_percent):
        self._actual_atomic_percent = self._get_object(FieldOperation, actual_atomic_percent)

    @actual_atomic_percent.deleter
    def actual_atomic_percent(self):
        self._actual_atomic_percent = None

    @property
    def ideal_weight_percent(self):
        return self._ideal_weight_percent

    @ideal_weight_percent.setter
    def ideal_weight_percent(self, ideal_weight_percent):
        self._ideal_weight_percent = self._get_object(FieldOperation, ideal_weight_percent)

    @ideal_weight_percent.deleter
    def ideal_weight_percent(self):
        self._ideal_weight_percent = None

    @property
    def ideal_atomic_percent(self):
        return self._ideal_atomic_percent

    @ideal_atomic_percent.setter
    def ideal_atomic_percent(self, ideal_atomic_percent):
        self._ideal_atomic_percent = self._get_object(FieldOperation, ideal_atomic_percent)

    @ideal_atomic_percent.deleter
    def ideal_atomic_percent(self):
        self._ideal_atomic_percent = None



from setuptools import setup, find_packages

setup(name='citrination-client',
      version='1.1.21',
      url='http://github.com/CitrineInformatics/python-citrination-client',
      description='Python client for accessing the Citrination api',
      packages=find_packages(),
      install_requires=[
          'requests==2.10.0',
          'pypif==1.0.24',
          'six==1.10.0'
      ])



from pypif.util.serializable import Serializable


class BaseFieldOperation(Serializable):
    """
    Base class for all field operations.
    """

    def __init__(self, extract_as=None, length=None, offset=None):
        """
        Constructor.

        :param extract_as: String with the alias to save this field under.
        :param length: One or more :class:`.FieldOperation` operations against the length field.
        :param offset: One or more :class:`.FieldOperation` operations against the offset field.
        """
        self._extract_as = None
        self.extract_as = extract_as
        self._length = None
        self.length = length
        self._offset = None
        self.offset = offset

    @property
    def extract_as(self):
        return self._extract_as

    @extract_as.setter
    def extract_as(self, extract_as):
        self._extract_as = extract_as

    @extract_as.deleter
    def extract_as(self):
        self._extract_as = None

    @property
    def length(self):
        return self._length

    @length.setter
    def length(self, length):
        from citrination_client.search.pif.query.core.field_operation import FieldOperation
        self._length = self._get_object(FieldOperation, length)

    @length.deleter
    def length(self):
        self._length = None

    @property
    def offset(self):
        return self._offset

    @offset.setter
    def offset(self, offset):
        from citrination_client.search.pif.query.core.field_operation import FieldOperation
        self._offset = self._get_object(FieldOperation, offset)

    @offset.deleter
    def offset(self):
        self._offset = None
